@@ -772,3 +772,61 @@ def PscAutoConnections(
           'specified.'
       )
   return updated_psc_auto_connections
+
+
+def FinalBackupConfiguration(
+    sql_messages,
+    instance=None,
+    final_backup_enabled=None,
+    final_backup_ttl_days=None,
+):
+  """Generates the Final Backup configuration for the instance.
+
+  Args:
+    sql_messages: module, The messages module that should be used.
+    instance: sql_messages.DatabaseInstance, the original instance, if the
+      previous state is needed.
+    final_backup_enabled: boolean, True if final backup should be enabled.
+    final_backup_ttl_days: int, how many days to retain the final backup.
+
+  Returns:
+    sql_messages.FinalBackupConfiguration object, or None
+
+  Raises:
+    ToolException: Bad combination of arguments.
+  """
+  should_generate_config = any([
+      final_backup_enabled is not None,
+      final_backup_ttl_days is not None,
+  ])
+
+  if not should_generate_config:
+    return None
+
+  # final_backup_enabled is explicitly set to False.
+  # final_backup_ttl_days should not be set using gcloud.
+  if final_backup_enabled is not None and not final_backup_enabled:
+    if final_backup_ttl_days is not None:
+      raise sql_exceptions.ArgumentError(
+          'Argument --final-backup-ttl-days should not be set when final'
+          ' backup is disabled.'
+      )
+
+  if not instance or not instance.settings.finalBackupConfig:
+    final_backup_config = sql_messages.FinalBackupConfig()
+  else:
+    final_backup_config = instance.settings.finalBackupConfig
+
+  # Generate new final backup config based on the gcloud arguments.
+  if final_backup_enabled is not None:
+    final_backup_config.enabled = final_backup_enabled
+  if final_backup_ttl_days is not None:
+    final_backup_config.ttlDays = final_backup_ttl_days
+    # Final backup enabled set to true if ttl days specified.
+    final_backup_config.enabled = True
+
+  # final_backup_enabled is set to False, we need to cleanup the ttl days.
+  if final_backup_enabled is not None and not final_backup_enabled:
+    final_backup_config.ttlDays = None
+
+  return final_backup_config
